==> tencentcloud-sdk-java-3.1.210-sources.jar: com/tencentcloudapi/mps/v20190612/models/LiveStreamAiRecognitionResultInfo.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.mps.v20190612.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class LiveStreamAiRecognitionResultInfo extends AbstractModel{

    /**
    * 内容识别结果列表。
    */
    @SerializedName("ResultSet")
    @Expose
    private LiveStreamAiRecognitionResultItem [] ResultSet;

    /**
     * Get 内容识别结果列表。 
     * @return ResultSet 内容识别结果列表。
     */
    public LiveStreamAiRecognitionResultItem [] getResultSet() {
        return this.ResultSet;
    }

    /**
     * Set 内容识别结果列表。
     * @param ResultSet 内容识别结果列表。
     */
    public void setResultSet(LiveStreamAiRecognitionResultItem [] ResultSet) {
        this.ResultSet = ResultSet;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "ResultSet.", this.ResultSet);

    }
}

==> tencentcloud-sdk-java-3.1.281-sources.jar: com/tencentcloudapi/mps/v20190612/models/LiveStreamAiRecognitionResultInfo.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.mps.v20190612.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class LiveStreamAiRecognitionResultInfo extends AbstractModel{

    /**
    * 内容识别结果列表。
    */
    @SerializedName("ResultSet")
    @Expose
    private LiveStreamAiRecognitionResultItem [] ResultSet;

    /**
     * Get 内容识别结果列表。 
     * @return ResultSet 内容识别结果列表。
     */
    public LiveStreamAiRecognitionResultItem [] getResultSet() {
        return this.ResultSet;
    }

    /**
     * Set 内容识别结果列表。
     * @param ResultSet 内容识别结果列表。
     */
    public void setResultSet(LiveStreamAiRecognitionResultItem [] ResultSet) {
        this.ResultSet = ResultSet;
    }

    public LiveStreamAiRecognitionResultInfo() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public LiveStreamAiRecognitionResultInfo(LiveStreamAiRecognitionResultInfo source) {
        if (source.ResultSet != null) {
            this.ResultSet = new LiveStreamAiRecognitionResultItem[source.ResultSet.length];
            for (int i = 0; i < source.ResultSet.length; i++) {
                this.ResultSet[i] = new LiveStreamAiRecognitionResultItem(source.ResultSet[i]);
            }
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "ResultSet.", this.ResultSet);

    }
}
